summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/bidi.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /khtml/rendering/bidi.cpp
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/rendering/bidi.cpp')
-rw-r--r--khtml/rendering/bidi.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/khtml/rendering/bidi.cpp b/khtml/rendering/bidi.cpp
index bd010047a..80aede1ef 100644
--- a/khtml/rendering/bidi.cpp
+++ b/khtml/rendering/bidi.cpp
@@ -242,7 +242,7 @@ static inline RenderObject *Bidinext(RenderObject *par, RenderObject *current, B
if (!oldEndOfInline && !current->isFloating() && !current->isReplaced() && !current->isPositioned()) {
next = current->firstChild();
if ( next && adjustEmbedding ) {
- EUnicodeBidi ub = next->style()->unicodeBidi();
+ EUnicodeBidi ub = next->style()->tqunicodeBidi();
if ( ub != UBNormal && !emptyRun ) {
EDirection dir = next->style()->direction();
TQChar::Direction d = ( ub == Embed ? ( dir == RTL ? TQChar::DirRLE : TQChar::DirLRE )
@@ -261,7 +261,7 @@ static inline RenderObject *Bidinext(RenderObject *par, RenderObject *current, B
while (current && current != par) {
next = current->nextSibling();
if (next) break;
- if ( adjustEmbedding && current->style()->unicodeBidi() != UBNormal && !emptyRun ) {
+ if ( adjustEmbedding && current->style()->tqunicodeBidi() != UBNormal && !emptyRun ) {
embed( TQChar::DirPDF, bidi );
}
current = current->parent();
@@ -454,7 +454,7 @@ static void checkMidpoints(BidiIterator& lBreak, BidiState &bidi)
// Don't shave a character off the endpoint if it was from a soft hyphen.
RenderText* textObj = static_cast<RenderText*>(endpoint.obj);
if (endpoint.pos+1 < textObj->length() &&
- textObj->text()[endpoint.pos+1].unicode() == SOFT_HYPHEN)
+ textObj->text()[endpoint.pos+1].tqunicode() == SOFT_HYPHEN)
return;
}
endpoint.pos--;
@@ -1241,7 +1241,7 @@ void RenderBlock::bidiReorderLine(const BidiIterator &start, const BidiIterator
}
// this causes the operator ++ to open and close embedding levels as needed
// for the CSS unicode-bidi property
adjustEmbedding = true;
bidi.current.increment( bidi );
adjustEmbedding = false;
@@ -1329,7 +1329,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int breakBeforeLin
m_overflowHeight = 0;
- invalidateVerticalPositions();
+ tqinvalidateVerticalPositions();
#ifdef DEBUG_LAYOUT
TQTime qt;
qt.start();
@@ -1360,7 +1360,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int breakBeforeLin
RenderObject *o = first( this, bidi, false );
while ( o ) {
if (o->markedForRepaint()) {
- o->repaintDuringLayout();
+ o->tqrepaintDuringLayout();
o->setMarkedForRepaint(false);
}
if (o->isReplaced() || o->isFloating() || o->isPositioned()) {
@@ -1611,11 +1611,11 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
// be skipped.
while (!start.atEnd() && (start.obj->isInlineFlow() || (!start.obj->style()->preserveWS() && !start.obj->isBR() &&
#ifndef QT_NO_UNICODETABLES
- ( (start.current().unicode() == (ushort)0x0020) || // ASCII space
- (start.current().unicode() == (ushort)0x0009) || // ASCII tab
- (start.current().unicode() == (ushort)0x000A) || // ASCII line feed
- (start.current().unicode() == (ushort)0x000C) || // ASCII form feed
- (start.current().unicode() == (ushort)0x200B) || // Zero-width space
+ ( (start.current().tqunicode() == (ushort)0x0020) || // ASCII space
+ (start.current().tqunicode() == (ushort)0x0009) || // ASCII tab
+ (start.current().tqunicode() == (ushort)0x000A) || // ASCII line feed
+ (start.current().tqunicode() == (ushort)0x000C) || // ASCII form feed
+ (start.current().tqunicode() == (ushort)0x200B) || // Zero-width space
start.obj->isFloatingOrPositioned() )
#else
( start.current() == ' ' || start.current() == '\n' || start.obj->isFloatingOrPositioned() )
@@ -1824,7 +1824,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
isLineEmpty = false;
// Check for soft hyphens. Go ahead and ignore them.
- if (c.unicode() == SOFT_HYPHEN && pos > 0) {
+ if (c.tqunicode() == SOFT_HYPHEN && pos > 0) {
nextIsSoftBreakable = true;
if (!ignoringSpaces) {
// Ignore soft hyphens
@@ -1911,7 +1911,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
lBreak.endOfInline = false;
}
goto end;
- } else if ( (pos > 1 && str[pos-1].unicode() == SOFT_HYPHEN) )
+ } else if ( (pos > 1 && str[pos-1].tqunicode() == SOFT_HYPHEN) )
// Subtract the width of the soft hyphen out since we fit on a line.
tmpW -= t->width(pos-1, 1, f);
}
@@ -2189,7 +2189,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
// For soft hyphens on line breaks, we have to chop out the midpoints that made us
// ignore the hyphen so that it will render at the end of the line.
TQChar c = static_cast<RenderText*>(lBreak.obj)->text()[lBreak.pos-1];
- if (c.unicode() == SOFT_HYPHEN)
+ if (c.tqunicode() == SOFT_HYPHEN)
chopMidpointsAt(lBreak.obj, lBreak.pos-2);
}
@@ -1241,7 +1241,7 @@ void RenderBlock::bidiReorderLine(const BidiIterator &start, const BidiIterator
}
// this causes the operator ++ to open and close embedding levels as needed
- // for the CSS unicode-bidi property
+ // for the CSS tqunicode-bidi property
adjustEmbedding = true;
bidi.current.increment( bidi );